@@ -1,23 +1,12 @@
 
-## @knitr load
+## ----load,message=FALSE--------------------------------------------------
 library(cda)
 library(rgl)
 library(ggplot2)
+library(reshape2)
+library(plyr)
 
-
-## @knitr setup
-
-rgl_annotate = function(){
-  axes3d( labels = FALSE, tick = FALSE, edges=c("x", "y", "z") )
-axis3d(labels = FALSE, tick = FALSE, 'x',pos=c(NA, 0, 0))
-axis3d(labels = FALSE, tick = FALSE, 'y',pos=c(0, NA, 0))
-axis3d(labels = FALSE, tick = FALSE, 'z',pos=c(0, 0, NA))
-title3d('','','x axis','y axis','z axis')
-}
-theme_set(theme_minimal())
-
-
-## @knitr cluster
+## ----cluster, rgl=TRUE,echo=-12,tidy=FALSE,fig.width=3,fig.height=3,fig.path="dimercd-"----
 
 # dielectric function
 wvl <- seq(400, 900)
@@ -35,7 +24,7 @@ rgl_annotate()
 
 
 
-## @knitr comparison
+## ----comparison,echo=TRUE,tidy=FALSE,fig.path="dimercd-",fig.width=8-----
   
 dimer <- function(dihedral=45, ...){
   cl <- cluster_dimer(dihedral = dihedral * pi/180, ...)
@@ -52,7 +41,7 @@ p <-
   facet_grid(type~variable, scales="free") +
   geom_line(aes(wavelength, value, 
                 colour=factor(dihedral))) +
-  labs(y=expression(sigma[ext]*" /"*nm^2),
+  labs(y=expression(sigma*" /"*nm^2),
        x=expression(wavelength*" /"*nm), colour="dihedral angle") +
          scale_colour_brewer(type="div", palette=3)
 
