@@ -1,15 +1,12 @@
 
-## @knitr load
+## ----load,message=FALSE--------------------------------------------------
 library(cda)
 library(rgl)
 library(ggplot2)
+library(reshape2)
+library(plyr)
 
-
-## @knitr setup
-theme_set(theme_minimal())
-
-
-## @knitr comparison
+## ----comparison,echo=TRUE,tidy=FALSE,fig.path="array-",fig.width=10, warning=FALSE----
 data(G0)
 
 ## number of dipoles for the numerical evaluation
